summaryrefslogtreecommitdiffstats
path: root/movement
diff options
context:
space:
mode:
Diffstat (limited to 'movement')
-rwxr-xr-xmovement/make/make_alternate_fw.sh4
-rw-r--r--movement/movement.c54
-rw-r--r--movement/movement.h1
-rw-r--r--movement/movement_config.h2
-rw-r--r--movement/template/template.c1
-rw-r--r--movement/watch_faces/clock/repetition_minute_face.c2
-rw-r--r--movement/watch_faces/clock/simple_clock_face.c4
-rw-r--r--movement/watch_faces/complication/tomato_face.c10
-rw-r--r--movement/watch_faces/complication/tomato_face.h1
-rw-r--r--movement/watch_faces/settings/nanosec_face.c1
10 files changed, 50 insertions, 30 deletions
diff --git a/movement/make/make_alternate_fw.sh b/movement/make/make_alternate_fw.sh
index c65e72d3..df27403f 100755
--- a/movement/make/make_alternate_fw.sh
+++ b/movement/make/make_alternate_fw.sh
@@ -21,12 +21,12 @@ do
for color in "${colors[@]}"
do
COLOR=$(echo "$color" | tr '[:lower:]' '[:upper:]')
- make clean
+ make COLOR=$COLOR clean
make COLOR=$COLOR FIRMWARE=$VARIANT
mv "build/watch.uf2" "$fw_dir/$variant-$color.uf2"
done
rm -rf ./build-sim
- emmake make FIRMWARE=$VARIANT
+ emmake make COLOR=GREEN FIRMWARE=$VARIANT
mkdir "$sim_dir/$variant/"
mv "build-sim/watch.wasm" "$sim_dir/$variant/"
mv "build-sim/watch.js" "$sim_dir/$variant/"
diff --git a/movement/movement.h b/movement/movement.h
index a0abd3f9..1dabfbc5 100644
--- a/movement/movement.h
+++ b/movement/movement.h
@@ -307,7 +307,6 @@ void movement_cancel_background_task_for_face(uint8_t watch_face_index);
void movement_request_wake(void);
void movement_play_signal(void);
-void movement_play_tune(void);
void movement_play_alarm(void);
void movement_play_alarm_beeps(uint8_t rounds, BuzzerNote alarm_note);
diff --git a/movement/movement_config.h b/movement/movement_config.h
index 6a7f87e0..067ca44b 100644
--- a/movement/movement_config.h
+++ b/movement/movement_config.h
@@ -49,7 +49,7 @@ const watch_face_t watch_faces[] = {
*/
#define MOVEMENT_SECONDARY_FACE_INDEX (MOVEMENT_NUM_FACES - 2) // or (0)
-/* Custom hourly chime tune. Check movement_custom_signal_tunes.h for options */
+/* Custom hourly chime tune. Check movement_custom_signal_tunes.h for options. */
#define SIGNAL_TUNE_DEFAULT
#endif // MOVEMENT_CONFIG_H_
diff --git a/movement/template/template.c b/movement/template/template.c
index e03db561..fe2723b8 100644
--- a/movement/template/template.c
+++ b/movement/template/template.c
@@ -28,6 +28,7 @@
void <#watch_face_name#>_face_setup(movement_settings_t *settings, uint8_t watch_face_index, void ** context_ptr) {
(void) settings;
+ (void) watch_face_index;
if (*context_ptr == NULL) {
*context_ptr = malloc(sizeof(<#watch_face_name#>_state_t));
memset(*context_ptr, 0, sizeof(<#watch_face_name#>_state_t));
diff --git a/movement/watch_faces/clock/repetition_minute_face.c b/movement/watch_faces/clock/repetition_minute_face.c
index fc78b2d8..e9e5e319 100644
--- a/movement/watch_faces/clock/repetition_minute_face.c
+++ b/movement/watch_faces/clock/repetition_minute_face.c
@@ -151,6 +151,8 @@ bool repetition_minute_face_loop(movement_event_t event, movement_settings_t *se
else watch_clear_indicator(WATCH_INDICATOR_BELL);
break;
case EVENT_BACKGROUND_TASK:
+ // uncomment this line to snap back to the clock face when the hour signal sounds:
+ // movement_move_to_face(state->watch_face_index);
movement_play_signal();
break;
case EVENT_LIGHT_LONG_UP:
diff --git a/movement/watch_faces/clock/simple_clock_face.c b/movement/watch_faces/clock/simple_clock_face.c
index ac9a97b2..fbc2c4b3 100644
--- a/movement/watch_faces/clock/simple_clock_face.c
+++ b/movement/watch_faces/clock/simple_clock_face.c
@@ -136,11 +136,7 @@ bool simple_clock_face_loop(movement_event_t event, movement_settings_t *setting
case EVENT_BACKGROUND_TASK:
// uncomment this line to snap back to the clock face when the hour signal sounds:
// movement_move_to_face(state->watch_face_index);
- #ifdef SIGNAL_TUNE_DEFAULT
movement_play_signal();
- #else
- movement_play_tune();
- #endif
break;
default:
return movement_default_loop_handler(event, settings);
diff --git a/movement/watch_faces/complication/tomato_face.c b/movement/watch_faces/complication/tomato_face.c
index 698301e1..3d46ba94 100644
--- a/movement/watch_faces/complication/tomato_face.c
+++ b/movement/watch_faces/complication/tomato_face.c
@@ -84,8 +84,10 @@ static void tomato_draw(tomato_state_t *state) {
sec = 0;
break;
}
- sprintf(buf, "TO %c%2d%02d%2d", kind, min, sec, state->done_count);
- watch_display_string(buf, 0);
+ if (state->visible) {
+ sprintf(buf, "TO %c%2d%02d%2d", kind, min, sec, state->done_count);
+ watch_display_string(buf, 0);
+ }
}
static void tomato_reset(tomato_state_t *state) {
@@ -116,6 +118,7 @@ void tomato_face_setup(movement_settings_t *settings, uint8_t watch_face_index,
state->mode=tomato_ready;
state->kind= tomato_focus;
state->done_count = 0;
+ state->visible = true;
}
}
@@ -127,6 +130,7 @@ void tomato_face_activate(movement_settings_t *settings, void *context) {
watch_set_indicator(WATCH_INDICATOR_BELL);
}
watch_set_colon();
+ state->visible = true;
}
bool tomato_face_loop(movement_event_t event, movement_settings_t *settings, void *context) {
@@ -184,6 +188,8 @@ bool tomato_face_loop(movement_event_t event, movement_settings_t *settings, voi
}
void tomato_face_resign(movement_settings_t *settings, void *context) {
+ tomato_state_t *state = (tomato_state_t *)context;
+ state->visible = false;
(void) settings;
(void) context;
}
diff --git a/movement/watch_faces/complication/tomato_face.h b/movement/watch_faces/complication/tomato_face.h
index 33a086c6..25f7db0e 100644
--- a/movement/watch_faces/complication/tomato_face.h
+++ b/movement/watch_faces/complication/tomato_face.h
@@ -64,6 +64,7 @@ typedef struct {
tomato_mode mode;
tomato_kind kind;
uint8_t done_count;
+ bool visible;
} tomato_state_t;
void tomato_face_setup(movement_settings_t *settings, uint8_t watch_face_index, void ** context_ptr);
diff --git a/movement/watch_faces/settings/nanosec_face.c b/movement/watch_faces/settings/nanosec_face.c
index 72fdb729..37dd08ef 100644
--- a/movement/watch_faces/settings/nanosec_face.c
+++ b/movement/watch_faces/settings/nanosec_face.c
@@ -245,7 +245,6 @@ static void value_increase(int16_t delta) {
nanosec_state.correction_cadence = (delta > 0) ? 1 : 20;
break;
}
- nanosec_state.correction_profile = (nanosec_state.correction_profile + delta) % nanosec_profile_count;
break;
case 6: // Aging
nanosec_state.aging_ppm_pa += delta;
diff --git a/movement/movement.c b/movement/movement.c
index 05b2a078..29832ba8 100644
--- a/movement/movement.c
+++ b/movement/movement.c
@@ -294,25 +294,31 @@ void movement_request_wake() {
_movement_reset_inactivity_countdown();
}
-void movement_play_signal(void) {
- bool buzzer_enabled = watch_is_buzzer_or_led_enabled();
- if (!buzzer_enabled) {
- watch_enable_buzzer();
- }
- watch_buzzer_play_note(BUZZER_NOTE_C8, 75);
- watch_buzzer_play_note(BUZZER_NOTE_REST, 100);
- watch_buzzer_play_note(BUZZER_NOTE_C8, 100);
- if (!buzzer_enabled) {
- watch_disable_buzzer();
- }
+void end_buzzing() {
+ movement_state.is_buzzing = false;
}
-void movement_play_tune(void) {
- if (!watch_is_buzzer_or_led_enabled()) {
- watch_enable_buzzer();
- watch_buzzer_play_sequence(signal_tune, watch_disable_buzzer);
+void end_buzzing_and_disable_buzzer(void) {
+ end_buzzing();
+ watch_disable_buzzer();
+}
+
+void movement_play_signal(void) {
+ void *maybe_disable_buzzer = end_buzzing_and_disable_buzzer;
+ if (watch_is_buzzer_or_led_enabled()) {
+ maybe_disable_buzzer = end_buzzing;
} else {
- watch_buzzer_play_sequence(signal_tune, NULL);
+ watch_enable_buzzer();
+ }
+ movement_state.is_buzzing = true;
+ watch_buzzer_play_sequence(signal_tune, maybe_disable_buzzer);
+ if (movement_state.le_mode_ticks == -1) {
+ // the watch is asleep. wake it up for "1" round through the main loop.
+ // the sleep_mode_app_loop will notice the is_buzzing and note that it
+ // only woke up to beep and then it will spinlock until the callback
+ // turns off the is_buzzing flag.
+ movement_state.needs_wake = true;
+ movement_state.le_mode_ticks = 1;
}
}
@@ -446,6 +452,7 @@ static void _sleep_mode_app_loop(void) {
bool app_loop(void) {
wf = &watch_faces[movement_state.current_face_idx];
+ bool woke_up_for_buzzer = false;
if (movement_state.watch_face_changed) {
if (movement_state.settings.bit.button_should_sound) {
// low note for nonzero case, high note for return to watch_face 0
@@ -491,7 +498,11 @@ bool app_loop(void) {
// _sleep_mode_app_loop takes over at this point and loops until le_mode_ticks is reset by the extwake handler,
// or wake is requested using the movement_request_wake function.
_sleep_mode_app_loop();
- // as soon as _sleep_mode_app_loop returns, we reactivate ourselves.
+ // as soon as _sleep_mode_app_loop returns, we prepare to reactivate
+ // ourselves, but first, we check to see if we woke up for the buzzer:
+ if (movement_state.is_buzzing) {
+ woke_up_for_buzzer = true;
+ }
event.event_type = EVENT_ACTIVATE;
// this is a hack tho: waking from sleep mode, app_setup does get called, but it happens before we have reset our ticks.
// need to figure out if there's a better heuristic for determining how we woke up.
@@ -582,8 +593,13 @@ bool app_loop(void) {
// if the watch face changed, we can't sleep because we need to update the display.
if (movement_state.watch_face_changed) can_sleep = false;
- // if the buzzer or the LED is on, we need to stay awake to keep the TCC running.
- if (movement_state.is_buzzing || movement_state.light_ticks != -1) can_sleep = false;
+ // if we woke up for the buzzer, stay awake until it's finished.
+ if (woke_up_for_buzzer) {
+ while(watch_is_buzzer_or_led_enabled());
+ }
+
+ // if the LED is on, we need to stay awake to keep the TCC running.
+ if (movement_state.light_ticks != -1) can_sleep = false;
return can_sleep;
}